module Testcloud
  module Devices
    class Client
      include HTTParty
      include Testcloud::Devices::Resources

      API_TOKEN_KEY ||= 'X-Testcloud-Devices-Token'

      attr_accessor :type, :category, :api_token, :raw_response, :response

      delegate :ok?,        to: :raw_response
      delegate :success?,   to: :raw_response
      delegate :code,       to: :raw_response
      delegate :config,     to: 'Testcloud::Devices::Client'

      class << self
        attr_reader :config
        def setup(&block)
          @config = Testcloud::Devices::Config.new
          yield(@config)
        end
      end

      def initialize(options = {})
        @type, @category = options[:type], options[:category]
        self.class.debug_output if options[:debug]
        self.class.base_uri(options[:url] || config.url || Testcloud::Devices::Config::DEFAULT_URL)
        config.api_token = options[:api_token] if options[:api_token]
      end

      def errors?
        return true if raw_response.code >= 300
        return true if response.has_key?(:errors)
        false
      end

      private
        def access_headers
          @access_headers ||= { headers: { API_TOKEN_KEY => config.api_token, 'Content-Type' => 'application/json' } }
        end

    end
  end
end
