module Testcloud
  module Devices
    module Resources
      extend ActiveSupport::Concern

      included do

        # Return all available device types
        def types
          @raw_response = @response = self.class.get('/devices/types', access_headers)
        end

        # Return all available categories for a given device type
        def categories
          @raw_response = self.class.get("/devices/#{type.pluralize}/categories", access_headers)
          @response = Response.new(@raw_response).keys
        end

        # Takes device parameters, validates them, and returns the correct device hash
        # an 'errors' key is always present if anything goes wrong.
        def validate(data = {})
          @raw_response = self.class.post("/devices/#{type}/#{category}", access_headers.merge(body: data.to_json))
          @response = Response.new(@raw_response)
        end

        # Get form data for a type and category (such as os, os_version, vendor, device models)
        def form_data
          @raw_response = self.class.get("/devices/#{type}/#{category}/form_data", access_headers)
          @response = Response.new(@raw_response)
        end

        # Submit a device that's missing from the database
        def report_missing_device(data = {})
          @raw_response = self.class.post("/devices/report_missing", access_headers.merge(body: data.to_json))
          @response = Response.new(@raw_response)
        end

      end
    end
  end
end
